==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federation/l10n/es.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Añadido a la lista de servidores de confianza",
    "Server is already in the list of trusted servers." : "El servidor ya está en la lista de servidores en los que se confía.",
    "No server to federate with found" : "No se ha encontrado ningún servidor con el que federarse.",
    "Could not add server" : "No se ha podido añadir el servidor",
    "Federation" : "Federación",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federación te permite conectar con otros servidores de confianza para intercambiar el directorio de usuarios.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "La federación permite conectarte con otros servidores de confianza para intercambiar directorios. Por ejemplo, esto se usará para autocompletar la selección de usuarios externos al compartir en federación.",
    "Trusted servers" : "Servidores de confianza",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "La Federación le permite conectarse con otros servidores de confianza para intercambiar el directorio de usuarios. Por ejemplo, esto se utilizará para autocompletar a los usuarios externos para el intercambio federado. No es necesario añadir un servidor como servidor de confianza para crear una recurso compartido federado.",
    "Add server automatically once a federated share was created successfully" : "Añadir el servidor automáticamente una vez que un compartido federado se haya creado exitosamente",
    "+ Add trusted server" : "+ Añadir servidor de confianza",
    "Trusted server" : "Servidor de confianza",
    "Add" : "Añadir"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federation/l10n/es.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Añadido a la lista de servidores de confianza",
    "Server is already in the list of trusted servers." : "El servidor ya está en la lista de servidores en los que se confía.",
    "No server to federate with found" : "No se ha encontrado ningún servidor con el que federarse.",
    "Could not add server" : "No se ha podido añadir el servidor",
    "Trusted servers" : "Servidores de confianza",
    "Federation" : "Federación",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federación te permite conectar con otros servidores de confianza para intercambiar el directorio de usuarios.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "La federación permite conectarte con otros servidores de confianza para intercambiar directorios. Por ejemplo, esto se usará para autocompletar la selección de usuarios externos al compartir en federación.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "La Federación le permite conectarse con otros servidores de confianza para intercambiar el directorio de usuarios. Por ejemplo, esto se utilizará para auto-completar a los usuarios externos para el intercambio federado. No es necesario añadir un servidor como servidor de confianza para crear una recurso compartido federado.",
    "+ Add trusted server" : "+ Añadir servidor de confianza",
    "Trusted server" : "Servidor de confianza",
    "Add" : "Añadir"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
